==> git-pm-1.1.5.tar.gz: git-pm-1.1.5/git_pm/lib/text.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-

##imports
#stdlib
import shutil


def fill(string, split_char=" "):
    max_size = shutil.get_terminal_size()[0]
    if len(string) < max_size:
        return string.ljust(max_size, ' ')
    else:
        lines = [[]]
        for word in string.split(split_char):
            if len(' '.join(lines[-1])+' '+word) < max_size:
                lines[-1].append(word)
            else:
                lines.append([word])
        lines = [ ' '.join(line).ljust(max_size, ' ') for line in lines]
        return "\n".join(lines)

def center(string, multiple_lines=False, fill=' '):
    if multiple_lines:
        return "\n".join([center(line.strip(), False) for line in string.split('\n')])
    else:
        space = shutil.get_terminal_size()[0] - len(string)
        offset = int(space/2)
        return fill*(offset+len(string)%2) + string + fill*offset


def bold(string):
    """Returns a string that will be printed in bold"""
    return("\033[1m"+string+"\033[21m")

def underline(string):
    """Returns a string that will be printed underlined"""
    return("\033[4m"+string+"\033[24m")

def invert(string):
    """Returns a string that will be printed inverted"""
    return("\033[7m"+string+"\033[27m")

def red(string):
    """Returns a string that will be printed in red"""
    return("\033[91m"+string+"\033[39m")

def blue(string):
    """Returns a string that will be printed in blue"""
    return("\033[94m"+string+"\033[39m")

def yellow(string):
    """Returns a string that will be printed in yellow"""
    return("\033[93m"+string+"\033[39m")

def magenta(string):
    """Returns a string that will be printed in magenta"""
    return("\033[95m"+string+"\033[39m")

def green(string):
    """Returns a string that will be printed in green"""
    return("\033[92m"+string+"\033[39m")

def grey(string):
    """Returns a string that will be printed in grey"""
    return("\033[90m"+string+"\033[39m")

def cyan(string):
    """Returns a string that will be printed in cyan"""
    return("\033[36m"+string+"\033[39m")

==> git-pm-1.1.16.tar.gz: git-pm-1.1.16/git_pm/lib/text.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-

##imports
#stdlib
import shutil


def fill(string, split_char=" "):
    """returns a string rjusted with split_char (default ' ') to the terminal size"""
    max_size = shutil.get_terminal_size()[0]
    if len(string) < max_size:
        return string.ljust(max_size, ' ')
    else:
        lines = [[]]
        for word in string.split(split_char):
            if len(' '.join(lines[-1])+' '+word) < max_size:
                lines[-1].append(word)
            else:
                lines.append([word])
        lines = [ ' '.join(line).ljust(max_size, ' ') for line in lines]
        return "\n".join(lines)

def center(string, multiple_lines=False, fill=' '):
    """returns a string ljusted and rjusted so that it can be printed in the center of the terminal"""
    if multiple_lines:
        return "\n".join([center(line.strip(), False) for line in string.split('\n')]) #recursive
    else:
        space = shutil.get_terminal_size()[0] - len(string)
        offset = int(space/2)
        return fill*(offset+len(string)%2) + string + fill*offset


def bold(string):
    """Returns a string that will be printed in bold"""
    return("\033[1m"+string+"\033[21m")

def underline(string):
    """Returns a string that will be printed underlined"""
    return("\033[4m"+string+"\033[24m")

def invert(string):
    """Returns a string that will be printed inverted"""
    return("\033[7m"+string+"\033[27m")

def red(string):
    """Returns a string that will be printed in red"""
    return("\033[91m"+string+"\033[39m")

def blue(string):
    """Returns a string that will be printed in blue"""
    return("\033[94m"+string+"\033[39m")

def yellow(string):
    """Returns a string that will be printed in yellow"""
    return("\033[93m"+string+"\033[39m")

def magenta(string):
    """Returns a string that will be printed in magenta"""
    return("\033[95m"+string+"\033[39m")

def green(string):
    """Returns a string that will be printed in green"""
    return("\033[92m"+string+"\033[39m")

def grey(string):
    """Returns a string that will be printed in grey"""
    return("\033[90m"+string+"\033[39m")

def cyan(string):
    """Returns a string that will be printed in cyan"""
    return("\033[36m"+string+"\033[39m")
